@@ -52,6 +52,7 @@
 #include "worker.h"
 #include "conf.h"
 #include "util.h"
+#include "module.h"
 
 /************************************************************************
  * Defines 
@@ -110,6 +111,7 @@ typedef struct response_s {
   char *body;
 } response_t;
 
+apr_status_t tcp_module_init(global_t *global);
 /************************************************************************
  * Implementation 
  ***********************************************************************/
@@ -237,7 +239,7 @@ static apr_status_t call_command(worker_t *worker, void *func, char *name, char
   command_t cmd;
   cmd.name = name;
   cmd.func = (command_f)func;
-  return cmd.func(&cmd, worker, params);
+  return cmd.func(&cmd, worker, params, worker->pbody);
 } 
 
 /**
@@ -264,10 +266,7 @@ static apr_status_t wait_request(worker_t * worker, request_t *r) {
 
   peeklen = worker->socket->peeklen;
   worker->socket->peeklen = 0;
-  if ((status = sockreader_new(&sockreader, worker->socket->socket,
-#ifdef USE_SSL
-                               worker->socket->is_ssl ? worker->socket->ssl : NULL,
-#endif
+  if ((status = sockreader_new(&sockreader, worker->socket->transport,
                                worker->socket->peek, peeklen, r->pool)) != APR_SUCCESS) {
     goto out_err;
   }
@@ -366,16 +365,13 @@ static apr_status_t wait_response(worker_t * worker, response_t *r) {
   r->body = NULL;
   r->len = 0;
 
-  if ((status = worker_flush(worker)) != APR_SUCCESS) {
+  if ((status = worker_flush(worker, worker->pbody)) != APR_SUCCESS) {
     return status;
   }
 
   peeklen = worker->socket->peeklen;
   worker->socket->peeklen = 0;
-  if ((status = sockreader_new(&sockreader, worker->socket->socket,
-#ifdef USE_SSL
-                               worker->socket->is_ssl ? worker->socket->ssl : NULL,
-#endif
+  if ((status = sockreader_new(&sockreader, worker->socket->transport,
                                worker->socket->peek, peeklen, r->pool)) != APR_SUCCESS) {
     goto out_err;
   }
@@ -813,6 +809,8 @@ static void *APR_THREAD_FUNC proxy_thread(apr_thread_t * thread, void *selfv) {
   memset(&global, 0, sizeof(global));
   global.log_mode = self->log_mode;
   global.socktmo = 1000 * 300000;
+  global.modules = apr_hash_make(self->pool);
+  global.blocks = apr_hash_make(self->pool);
   
   if ((status = worker_new(&server, "", "", &global, NULL)) != APR_SUCCESS) {
     apr_thread_exit(thread, status);
@@ -1163,9 +1161,18 @@ int proxy(self_t *self) {
   }
 
   memset(&global, 0, sizeof(global));
+  global.pool = self->pool;
   global.log_mode = self->log_mode;
   global.socktmo = 1000 * 300000;
-  
+  global.modules = apr_hash_make(self->pool);
+  global.blocks = apr_hash_make(self->pool);
+
+  /**
+   * Initialize tcp module
+   */
+
+  tcp_module_init(&global);
+
   if ((status = worker_new(&listener, "", "", &global, NULL)) != APR_SUCCESS) {
     return status;
   } 
@@ -1191,6 +1198,7 @@ int proxy(self_t *self) {
     worker_get_socket(client, "Default", "0");
     client->socket->socket_state = listener->socket->socket_state;
     client->socket->socket = listener->socket->socket;
+    client->socket->transport = listener->socket->transport;
 
     /* new thread */
     this = apr_pcalloc(client->pbody, sizeof(*this));
@@ -1400,7 +1408,9 @@ int main(int argc, const char *const argv[]) {
   else if (conf_file) {
     return -1;
   }
-  
+
+  apr_hook_global_pool = pool; 
+
   /* overwrites config */
   self->pool = pool;
   self->port = port;
@@ -1419,7 +1429,7 @@ int main(int argc, const char *const argv[]) {
   fprintf(stdout, "Start proxy on port %d\n", port);
   
   print_file(self, self->pre);
-  
+    
   proxy(self);
 
   fprintf(stdout, "\n--normal end\n");
