@@ -29,8 +29,6 @@
 #include <config.h>
 #endif
 
-#include <openssl/ssl.h>
-
 #include <apr.h>
 #include <apr_lib.h>
 #include <apr_strings.h>
@@ -38,6 +36,7 @@
 #include <apr_buckets.h>
 
 #include "defines.h"
+#include "transport.h"
 #include "socket.h"
 
 
@@ -47,10 +46,7 @@
 
 struct sockreader_s {
   apr_pool_t *pool;
-  apr_socket_t *socket;
-#ifdef USE_SSL
-  SSL *ssl;
-#endif
+  transport_t *transport;
   apr_size_t i;
   apr_size_t len;
   char *buf;
@@ -82,10 +78,7 @@ static char *my_strcasestr(const char *s1, const char *s2);
  *
  * @return APR_SUCCESS else an APR error
  */
-apr_status_t sockreader_new(sockreader_t ** sockreader, apr_socket_t * socket,
-#ifdef USE_SSL
-                            SSL * ssl,
-#endif
+apr_status_t sockreader_new(sockreader_t ** sockreader, transport_t *transport,
                             char *rest, apr_size_t len, apr_pool_t * p) {
   apr_status_t status;
   apr_allocator_t *allocator;
@@ -95,10 +88,7 @@ apr_status_t sockreader_new(sockreader_t ** sockreader, apr_socket_t * socket,
   (*sockreader)->alloc = apr_bucket_alloc_create(p);
   (*sockreader)->line = apr_brigade_create(p, (*sockreader)->alloc);
 
-  (*sockreader)->socket = socket;
-#ifdef USE_SSL
-  (*sockreader)->ssl = ssl;
-#endif
+  (*sockreader)->transport = transport;
   allocator = apr_pool_allocator_get(p);
   apr_allocator_max_free_set(allocator, 1024*1024);
   (*sockreader)->pool = p;
@@ -132,20 +122,6 @@ void sockreader_set_options(sockreader_t *self, int options) {
   self->options = options;
 }
 
-/** 
- * Get corresponding socket from sockreader
- *
- * @param self IN sockreader object
- *
- * @return socket
- */
-apr_socket_t * sockreader_get_socket(sockreader_t *self) {
-  if (!self) {
-    return NULL;
-  }
-  return self->socket;
-}
-
 /**
  * Push back a line
  *
@@ -198,6 +174,7 @@ apr_status_t sockreader_read_line(sockreader_t * self, char **line) {
 
   i = 0;
   c = 0;
+  apr_brigade_cleanup(self->line);
   while (c != '\n') {
     if (self->i >= self->len) {
       if ((status = sockreader_fill(self)) != APR_SUCCESS) {
@@ -209,7 +186,6 @@ apr_status_t sockreader_read_line(sockreader_t * self, char **line) {
       c = self->buf[self->i];
       apr_brigade_putc(self->line, NULL, NULL, c);
       self->i++;
-      i++;
     }
   }
 
@@ -626,47 +602,14 @@ static apr_status_t sockreader_fill(sockreader_t * self) {
     self->swap = NULL;
   }
 
-  if (!self->socket) {
-    return APR_ENOSOCKET;
-  }
-
   self->len = BLOCK_MAX;
 
-#ifdef USE_SSL
-  if (self->ssl) {
-  tryagain:
-    apr_sleep(1);
-    status = SSL_read(self->ssl, self->buf, self->len);
-    if (status <= 0) {
-      int scode = SSL_get_error(self->ssl, status);
-
-      if (scode == SSL_ERROR_ZERO_RETURN) {
-	self->len = 0;
-        return APR_EOF;
-      }
-      else if (scode != SSL_ERROR_WANT_WRITE && scode != SSL_ERROR_WANT_READ) {
-	self->len = 0;
-        return APR_ECONNABORTED;
-      }
-      else {
-        goto tryagain;
-      }
-    }
-    else {
-      self->len = status;
-      return APR_SUCCESS;
-    }
+  status = transport_read(self->transport, self->buf, &self->len);
+  if (APR_STATUS_IS_EOF(status) && self->len > 0) {
+    return APR_SUCCESS;
   }
-  else
-#endif
-  {
-    status = apr_socket_recv(self->socket, self->buf, &self->len);
-    if (APR_STATUS_IS_EOF(status) && self->len > 0) {
-      return APR_SUCCESS;
-    }
-    else {
-      return status;
-    }
+  else {
+    return status;
   }
 }
 
