@@ -91,7 +91,7 @@ static unsigned long ssl_util_thr_id(void);
 static void ssl_util_thr_lock(int mode, int type, const char *file, int line); 
 static int ssl_rand_choosenum(int l, int h); 
 static apr_status_t ssl_util_thread_cleanup(void *data); 
-static char *ssl_var_lookup_ssl_cert_dn(apr_pool_t *p, X509_NAME *xsname, char *var);
+static char *ssl_var_lookup_ssl_cert_dn(apr_pool_t *p, X509_NAME *xsname, const char *var);
 static char *ssl_var_lookup_ssl_cert_valid(apr_pool_t *p, ASN1_UTCTIME *tm);
 static char *ssl_var_lookup_ssl_cert_remain(apr_pool_t *p, ASN1_UTCTIME *tm);
 static char *ssl_var_lookup_ssl_cert_serial(apr_pool_t *p, X509 *xs);
@@ -441,7 +441,7 @@ ENGINE *setup_engine(BIO *err, const char *engine, int debug) {
  *
  * @return Variable value
  */
-char *ssl_var_lookup_ssl_cert(apr_pool_t *p, X509 *xs, char *var) {
+char *ssl_var_lookup_ssl_cert(apr_pool_t *p, X509 *xs, const char *var) {
     char *result;
     X509_NAME *xsname;
     int nid;
@@ -529,7 +529,7 @@ static const struct {
     { NULL,    0,                          0 }
 };
 
-static char *ssl_var_lookup_ssl_cert_dn(apr_pool_t *p, X509_NAME *xsname, char *var)
+static char *ssl_var_lookup_ssl_cert_dn(apr_pool_t *p, X509_NAME *xsname, const char *var)
 {
     char *result, *ptr;
     X509_NAME_ENTRY *xsne;
@@ -751,6 +751,26 @@ void modssl_var_extract_dns(apr_table_t *t, SSL *ssl, apr_pool_t *p)
     }
 }
 
+/**
+ * verify callback for peer cert verification for debugging purpose
+ * @param cur_ok IN current ok state
+ * @param ctx IN X509 store context
+ */
+int debug_verify_callback(int cur_ok, X509_STORE_CTX *ctx) {
+  char buf[256];
+  X509 *err_cert;
+  int err, depth;
+
+  err_cert = X509_STORE_CTX_get_current_cert(ctx);
+  err = X509_STORE_CTX_get_error(ctx);
+  depth = X509_STORE_CTX_get_error_depth(ctx);
+
+  X509_NAME_oneline(X509_get_subject_name(err_cert), buf, 256);
+  fprintf(stdout, "\nverify error:num=%d:%s:depth=%d:%s",
+	  err, X509_verify_cert_error_string(err), depth, buf);
+  return cur_ok;
+}
+
 #endif
 
 #endif
