@@ -6,8 +6,8 @@ for E in `ls *.hte`; do
   B=`echo $E | sed -e 's/\(.*\)\.hte/\1/'`
   if [ -f $B.txt ]; then
     CORES_PRE=`ls core* 2>/dev/null | wc -l` 
-    ./run.sh -e $B.hte 2>tmp.txt >/dev/null
-    diff tmp.txt $B.txt 
+    ./run.sh -e $B.hte 2>/tmp/tmp.txt >/dev/null
+    diff /tmp/tmp.txt $B.txt 
     ret=$?
     if [ $ret -ne 0 ]; then
       HTT_ERRORS=`expr $HTT_ERRORS + 1`
